Crate decoded_char
source · [−]Expand description
This is a very simple utility crate that provides a wrapper over char
values, DecodedChar, additionally storing the original byte length of the
character in the encoded source file.
It also provides wrappers around char iterators to produce DecodedChar
iterators from UTF-8/16 encoded sources.
Structs
Decoded character.
Iterator wrapper around fallible UTF-8 encoded sources.
Iterator wrapper around fallible UTF-16 encoded sources.
Iterator wrapper around UTF-8 encoded sources.
Iterator wrapper around UTF-16 encoded sources.
Traits
Extension for str providing the decoded_char method.