pub struct DecodedChar { /* private fields */ }
Decoded character.

A character and its original byte length in the encoded source file.

Implementations

Creates a new decoded character from its value, c, and its original byte length len in the encoded source file.

Creates a new decoded character, decoded from an UTF-8 encoded source file.

Creates a new decoded character, decoded from an UTF-16 encoded source file.

Returns the character.

Returns the original byte length of the character in the encoded source file.

Turns this DecodedChar into the underlying char.

Turns this DecodedChar into the original byte length in the encoded source file.