Struct decoded_char::DecodedChar
source · [−]pub struct DecodedChar { /* private fields */ }Expand description
Decoded character.
A character and its original byte length in the encoded source file.
Implementations
sourceimpl DecodedChar
impl DecodedChar
sourcepub fn new(c: char, len: usize) -> Self
pub fn new(c: char, len: usize) -> Self
Creates a new decoded character from its value, c,
and its original byte length len in the encoded source file.
sourcepub fn from_utf8(c: char) -> Self
pub fn from_utf8(c: char) -> Self
Creates a new decoded character, decoded from an UTF-8 encoded source file.
sourcepub fn from_utf16(c: char) -> Self
pub fn from_utf16(c: char) -> Self
Creates a new decoded character, decoded from an UTF-16 encoded source file.